@@ -1,4 +1,4 @@
 from .Algoritmos import MCTS
-from .Algoritmos import MinMax
+from .Algoritmos import Minimax
 from .Algoritmos import SOISMCTS
 from .Algoritmos import MOISMCTS
\ No newline at end of file
